#########################################################
#      FUNCTION  DEFINITIONS                            #
#                                                       #
#########################################################

#!/bin/ksh
#### PLEASE ONLY CHANGE THE PARTS WHERE THE LINE STARTS WITH THE WORD "MODIFY" ####

#### Set the APP_NAME to your application name such as for tseffmgr username it will be tseff
#### MODIFY APP NAME
export APP_NAME=myst

###### INITIATE BLOCK. DO NOT CHANGE ANYTHING IN INITIATE BLOCK #########

. /app/informatica/env/informatica.env
. $CODE_BASE/$APP_NAME/env/$APP_NAME.env
. $ADM_BASE/ISS_FUNC_LIB
issLib_BUILD_LOG $(basename $0)

###### END INITIATE BLOCK ################

### Set the jobs you need to run in the below section. All the jobs will run in serial in the order they are called.
###There are two valid job types: "WF" for Informatica Workflows, and SC for unix scripts.
###You can find two samples below one for each type.
###There is no limit to how many jobs you can set here among the above two types and in any order.





#Setup variables and directory structures
variables() 
{

    source="${1:-orddailyv4.dat}"
    file_type="${2:-ord}"
    myst_home=$INFA_SHARE
    #log="${myst_home}/ST/sql/${source}.log"
    log="${myst_home}/myst/ScriptLogs/${source}.log"
    file_param="${myst_home}/myst/SrcFiles/${source}.param"
    data="${myst_home}/myst/SrcFiles/"
    #file_dropoff="${myst_home}/InboundJails/mystsftp/inbound"
	file_dropoff="/DI_Data_AT1/collections/inbound_sftp_jails/./home/mystsftp/inbound"
    archive="${myst_home}/myst/archive"
    script=$CODE_BASE/myst/sh
 }

 ###################################################

 dir_exist() 
 {

# Check to make sure the directories exist:
 if [ ! -d "${myst_home}" ]
   then
     echo "The main file path ${myst_home} is not valid; quitting the script" >> ${log} 2>&1
     exit
   else
     echo "The main file path ${myst_home} is valid" >> ${log} 2>&1
 fi

# Check to make sure the directories exist:
 if [ ! -d "${data}" ]
   then
     echo "Data file path ${data} is not valid; quitting the script" >> ${log} 2>&1
     exit
   else
     echo "Data file path ${data} is valid" >> ${log} 2>&1
 fi
 }

 ###################################################

files_2_process()
{

#checkes to see if there are any files to process
  count=`ls ${file_dropoff}/*ord_extr_*MYST_20*[01]*.zip|wc -l`
  echo $count >> ${log} 2>&1

  if [ $count = 0 ]
   then
     echo "There are no files to process, exiting script" >>  ${log} 2>&1
     exit 1
   else
     echo "There are $count files to process" ${log} 2>&1
  fi
}

######################################################
#checks if orddailyv4.dat file exists before extracting new file

file_exist()
{
  cd ${data}
  if [ -r ${source} ]
   then
     echo "File ${source} already exists, not extracting the next file `date`" >> ${log} 2>&1
     echo "File ${source} already exists, not extracting the next file `date`"
     exit 1
   else
     echo "${source} doesn't exist, will start processing now" >> ${log} 2>&1
  fi
}

###################################################

#Loop while files exist, from oldest to newest; file names are sorted and first is selected
find_oldest_file() 
{
    oldest_file=`ls *ord_extr_*_MYST_20*[01]*.zip| sort | head -1`
    echo "Running ext_fdw_daily.ksh oldest file is ${oldest_file}" >> ${log} 2>&1
}

###################################################

#uses a list of emails to send out messages regarding the processing of current extract file
send_email() 
{
    function readEMAIL
    {
      mailx -s "${subject}" $info < error_message.tmp
    }

    while read -r info
    do
    readEMAIL
    done < mail.txt
}

##################################################

# Unzips EDW Order agg files via punzip.pl and makes a copy in archive and deletes files older than 7 days. 
punzip_files()
{
   ${script}/punzip.pl -f $oldest_file -d $file_dropoff 
   
   cp $oldest_file $archive
  
   find ${archive}/edw* -mtime +7 -type f -exec rm -f {} \; 

}

####################################################
# Renames files and moves them to the $INFA_SHARE/myst/Srcfiles directory 
file_setup()

{
    mv ${file_dropoff}/edw_ord_extr_agg_MYST_*.*.dat ${file_dropoff}/orddailyv4.dat
    mv ${file_dropoff}/orddailyv4.dat ${data}

}


####################################################
# Clean up hpsb inbound dir and set triger file for Informatica
cleanup_inbound()

{
    rm ${file_dropoff}/edw_ord_extr_agg_MYST_*.*.aud
    rm ${file_dropoff}/edw_ord_extr_agg_MYST_*.*.zip
    touch ${data}orddailyv4.trg
}

###################################################

file_size_ck()
{
  echo "checking file size to make sure we have data" >> ${log} 2>&1
  echo "checking file size to make sure we have data"
  echo ${source}
  file_size=`cat ${source}|wc -l`
  echo $file_size
  echo $ext

  if [ ${file_size} = 0 ]
   then
     echo "Problem with data file" > subject.tmp
     subject=`cat subject.tmp`
     echo "${oldest_file} is empty, please do a manual check" > error_message.tmp
     send_email
     rm error_message.tmp subject.tmp
   else
     touch orddailyv4.trg
  fi
}
######################################################




##########################################
#                                        #
#            MAIN SCRIPT                 #
##########################################

# Function to call informatica env
   env

#function call to variables
   variables

#Sets up a new entry in the log file

   echo "############################################" >> ${log}
   echo "Today's date is $dtime" >> ${log}
   echo "                      " >> ${log}
   echo "############################################" >> ${log}

#function call to check if directories exist
   dir_exist

#function call to check if there are files to process
   files_2_process

#function to call to check if data file exists
   file_exist

#function call to find oldest file
   cd ${file_dropoff}
   find_oldest_file

#function call to prepare the oldest file for processing
   punzip_files

#function call to punzip the data and prepare for loading
   file_setup 

#function call to check for zero file length 

#   file_size_ck

#function call to cleanup hpsb inbound  
   cleanup_inbound


dtime=`date +%C%y%m%d_%H%M`

   echo "############################################" >> ${log}
   echo "End of file processing --> $dtime" >> ${log}
   echo "                      " >> ${log}
   echo "############################################" >> ${log}

chmod 777 ${data}/orddailyv4.*
